%define common_summary interact with virtualization capabilities
%define common_description Libvirt is a C toolkit to interact with the virtualization\
capabilities of recent versions of Linux.
%define lib_major 0

%define lib_name %mklibname virt %{lib_major}
%define develname %mklibname -d virt
%define staticdevelname %mklibname -d -s virt

# libxenstore is not versionned properly
%define _requires_exceptions devel(libxenstore.*)

%define _disable_ld_as_needed 1

Name:       libvirt
Version:    0.6.1
Release:    %mkrel 4
Summary:    Toolkit to %{common_summary}
License:    LGPLv2+
Group:      System/Kernel and hardware
Url:        http://libvirt.org/
Source:     http://libvirt.org/sources/%{name}-%{version}.tar.gz
Patch0:     libvirt-0.6.1-init-lsb-headers.patch

# Fedora patches, from upstream source repository
Patch101: libvirt-0.6.1-xend-lookup.patch
Patch102: libvirt-0.6.1-xen-events.patch
Patch103: libvirt-0.6.1-events-dispatch.patch
Patch104: libvirt-0.6.1-fd-leaks.patch
Patch105: libvirt-0.6.1-getvcpus-remote.patch
Patch106: libvirt-0.6.1-pool-mode-parse.patch
Patch107: libvirt-0.6.1-storage-free.patch
Patch108: libvirt-0.6.1-vcpu-deadlock.patch
Patch109: libvirt-0.6.1-xenblock-detach.patch
Patch110: libvirt-0.6.1-fd-leaks2.patch
Patch111: libvirt-0.6.1-svirt-shared-readonly.patch

# XXX: for %%{_sysconfdir}/sasl2
Requires:   cyrus-sasl
BuildRequires:  xen-devel >= 3.0.4
BuildRequires:  libxml2-devel
BuildRequires:  ncurses-devel
BuildRequires:  readline-devel
BuildRequires:  python-devel
BuildRequires:  gnutls-devel
BuildRequires:  libsasl-devel
BuildRequires:  polkit-devel
BuildRequires:  hal-devel
BuildRequires:  parted-devel
BuildRequires:  open-iscsi
BuildRequires:  lvm2
BuildRequires:  libxml2-utils
BuildRequires:  libavahi-client-devel
BuildRoot: %{_tmppath}/%{name}-%{version}

%description
%{common_description}

Virtualization of the Linux Operating System means the
ability to run multiple instances of Operating Systems concurently on
a single hardware system where the basic resources are driven by a
Linux instance. The library aim at providing long term stable C API
initially for the Xen paravirtualization but should be able to
integrate other virtualization mechanisms if needed.

%package -n %{lib_name}
Summary:    A library to %{common_summary}
Group:      System/Libraries

%description -n %{lib_name}
%{common_description}

This package contains the library needed to run programs dynamically
linked with %{name}.

%package -n %{develname}
Summary:    Development tools for programs using %{name}
Group:      Development/C
Requires:   %{lib_name} = %{version}
Requires:   xen-devel
Provides:   %{name}-devel = %{version}-%{release}
Obsoletes:  %{lib_name}-devel

%description -n %{develname}
%{common_description}

This package contains the header files and libraries needed for
developing programs using the %{name} library.

%package -n %{staticdevelname}
Summary:    Development static libraries for programs using %{name}
Group:      Development/C
Provides:   %{name}-static-devel = %{version}-%{release}
Obsoletes:  %{lib_name}-static-devel

%description -n %{staticdevelname}
%{common_description}

This package contains the static libraries needed for developing
programs using the %{name} library.

%package -n python-%{name}
Summary:    Python bindings to %{common_summary}
Group:      Development/Python

%description -n python-%{name}
%{common_description}

This package contains the python bindings for the %{name} library.

%package -n %{name}-utils
Summary:    Tools to %{common_summary}
Group:      System/Kernel and hardware
Requires:   bridge-utils
Requires:   %{lib_name} = %{version}
Suggests:   dnsmasq-base
Suggests:	netcat-openbsd

%description -n %{name}-utils
%{common_description}

This package contains tools for the %{name} library.

%prep
%setup -q
%patch0 -p1 -b .lsb

%patch101 -p0
%patch102 -p0
%patch103 -p1
%patch104 -p1
%patch105 -p1
%patch106 -p1
%patch107 -p1
%patch108 -p1
%patch109 -p1
%patch110 -p0
%patch111 -p1

%build
%configure2_5x \
    --localstatedir=%{_var}  \
    --with-html-subdir=%{name} \
    --with-xen-proxy
%make

%install
rm -rf %{buildroot}
%makeinstall
install -d -m 755 %{buildroot}%{_var}/run/%{name}
install -d -m 755 %{buildroot}%{_var}/lib/%{name}
%find_lang %{name}

# fix documentation
mv %{buildroot}%{_docdir}/%{name}-python-%{version} %{buildroot}%{_docdir}/python-%{name}
install -m 644 ChangeLog README TODO NEWS %{buildroot}%{_docdir}/%{name}

%check
make check

%clean
rm -rf %{buildroot}

%if %mdkversion < 200900
%post -n %{lib_name} -p /sbin/ldconfig
%endif
%if %mdkversion < 200900
%postun -n %{lib_name} -p /sbin/ldconfig
%endif

%files -n %{lib_name} -f %{name}.lang
%defattr(-,root,root)
%dir %{_docdir}/%{name}
%{_docdir}/%{name}/ChangeLog
%{_docdir}/%{name}/README
%{_docdir}/%{name}/TODO
%{_docdir}/%{name}/NEWS
%{_libdir}/%{name}.so.%{lib_major}*

%files -n %{develname}
%defattr(-,root,root)
%{_docdir}/%{name}
%exclude %{_docdir}/%{name}/ChangeLog
%exclude %{_docdir}/%{name}/README
%exclude %{_docdir}/%{name}/TODO
%exclude %{_docdir}/%{name}/NEWS
%doc %{_datadir}/gtk-doc/html/%{name}
%{_includedir}/%{name}
%{_libdir}/%{name}.so
%{_libdir}/%{name}.la
%{_libdir}/libvirt_lxc
%{_libdir}/pkgconfig/%{name}.pc

%files -n %{staticdevelname}
%defattr(-,root,root)
%{_libdir}/%{name}.a

%files -n python-%{name}
%defattr(-,root,root)
%doc %{_docdir}/python-%{name}
%{py_platsitedir}/%{name}.py
%{py_platsitedir}/%{name}mod.a
%{py_platsitedir}/%{name}mod.la
%{py_platsitedir}/%{name}mod.so

%files -n %{name}-utils
%defattr(-,root,root)
%{_bindir}/*
%{_mandir}/man1/virsh.1*
%{_sbindir}/*
%{_initrddir}/libvirtd
%{_sysconfdir}/sysconfig/libvirtd
%{_sysconfdir}/logrotate.d/libvirtd
%{_libdir}/libvirt_proxy
%{_libdir}/libvirt_parthelper
%{_var}/run/libvirt
%{_var}/lib/libvirt
%{_datadir}/PolicyKit/policy/org.libvirt.unix.policy
%{_datadir}/augeas
%{_datadir}/%{name}
%config(noreplace) %{_sysconfdir}/libvirt
%config(noreplace) %{_sysconfdir}/sasl2/libvirt.conf


%changelog
* Wed May 06 2009 Guillaume Rousse <guillomovitch@mandriva.org> 0.6.1-4mdv2009.1
+ Revision: 372767
- add avahi support (fix #50407)

* Fri Apr 10 2009 Frederik Himpe <fhimpe@mandriva.org> 0.6.1-3mdv2009.1
+ Revision: 365915
- Don't restart libvirtd when resuming from hibernation, it breaks
  the pipe if virt-manager is left running and does not fix the
  IPv4 forwarding disabled problem after resume anyway

* Fri Mar 27 2009 Frederik Himpe <fhimpe@mandriva.org> 0.6.1-2mdv2009.1
+ Revision: 361522
- libvirtd uses messagebus, so change the init script so that it is
  started later than messagebus
- Add upstream bugfix patches from Fedora
- Restart libvirtd on resume after suspension, otherwise IP forwarding
  is not re-enabled after resume

* Thu Mar 05 2009 Frederik Himpe <fhimpe@mandriva.org> 0.6.1-1mdv2009.1
+ Revision: 349138
- BuildRequires libxml2-utils for xmllint, used by test suite
- Update to new version 0.6.1
- Patch init script to include LSB headers to start network and
  name resolution before libvirt, otherwise libvirt stops working
  if it's started too early
- Run test suite

* Wed Feb 25 2009 Guillaume Rousse <guillomovitch@mandriva.org> 0.6.0-2mdv2009.1
+ Revision: 344754
- rebuild against new readline

* Thu Feb 05 2009 Guillaume Rousse <guillomovitch@mandriva.org> 0.6.0-1mdv2009.1
+ Revision: 337832
- new version

* Mon Jan 19 2009 Guillaume Rousse <guillomovitch@mandriva.org> 0.5.1-3mdv2009.1
+ Revision: 331457
- utils package suggests netcat-openbsd (fix #46465)
- utils package should require same version of the lib
- no tabs, only spaces in spec file

* Fri Jan 02 2009 Funda Wang <fundawang@mandriva.org> 0.5.1-2mdv2009.1
+ Revision: 323417
- rebuild

* Mon Dec 08 2008 Guillaume Rousse <guillomovitch@mandriva.org> 0.5.1-1mdv2009.1
+ Revision: 311991
- new version

* Tue Dec 02 2008 Guillaume Rousse <guillomovitch@mandriva.org> 0.5.0-1mdv2009.1
+ Revision: 309482
- new version
- disable as_needed, it breaks HAL detection

* Mon Oct 27 2008 Frederik Himpe <fhimpe@mandriva.org> 0.4.6-3mdv2009.1
+ Revision: 297746
- Suggest dnsmasq-base: libvirt uses this package to provide DHCP and
  DNS services to virtual machines with NAT networking
- Create /var/lib/libvirt, where the dnsmasq leases file will be
  stored

* Tue Oct 14 2008 Frederik Himpe <fhimpe@mandriva.org> 0.4.6-2mdv2009.1
+ Revision: 293754
- Make libvirt-utils require bridge-utils, otherwise virsh fails to
  activate the virbr0 bridge

* Mon Oct 13 2008 Guillaume Rousse <guillomovitch@mandriva.org> 0.4.6-1mdv2009.1
+ Revision: 293116
- new version

* Thu Aug 14 2008 Guillaume Rousse <guillomovitch@mandriva.org> 0.4.4-2mdv2009.0
+ Revision: 272027
- make devel package requires xen-devel

* Tue Jul 01 2008 Guillaume Rousse <guillomovitch@mandriva.org> 0.4.4-1mdv2009.0
+ Revision: 230502
- update file list and build dependencies

  + Emmanuel Andry <eandry@mandriva.org>
    - New version

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

* Wed Apr 16 2008 Guillaume Rousse <guillomovitch@mandriva.org> 0.4.2-1mdv2009.0
+ Revision: 194590
- new version

  + Thierry Vignaud <tvignaud@mandriva.com>
    - fix no-buildroot-tag

* Mon Jan 21 2008 Funda Wang <fundawang@mandriva.org> 0.4.0-3mdv2008.1
+ Revision: 155530
- rebuild

* Tue Dec 18 2007 David Walluck <walluck@mandriva.org> 0.4.0-2mdv2008.1
+ Revision: 132143
- BuildRequires: libsasl-devel
- 0.4.0

  + Thierry Vignaud <tvignaud@mandriva.com>
    - kill re-definition of %%buildroot on Pixel's request

* Fri Dec 07 2007 Guillaume Rousse <guillomovitch@mandriva.org> 0.3.3-1mdv2008.1
+ Revision: 116159
- new version

* Sat Sep 22 2007 Guillaume Rousse <guillomovitch@mandriva.org> 0.3.2-2mdv2008.0
+ Revision: 92284
- new doc policy
- ship %%{_var}/run/libvirt directory for libvirtd
- fix nasty redefinition of standard GNU directory localstatedir by %%configure macro...

* Thu Aug 30 2007 Funda Wang <fundawang@mandriva.org> 0.3.2-1mdv2008.0
+ Revision: 75151
- New version 0.3.2

* Thu Jul 12 2007 Funda Wang <fundawang@mandriva.org> 0.3.0-1mdv2008.0
+ Revision: 51565
- fix file list
- New version

* Tue Jun 19 2007 Guillaume Rousse <guillomovitch@mandriva.org> 0.2.3-1mdv2008.0
+ Revision: 41371
- new version

* Sat Jun 02 2007 Guillaume Rousse <guillomovitch@mandriva.org> 0.2.2-1mdv2008.0
+ Revision: 34672
- new version


* Fri Feb 23 2007 Guillaume Rousse <guillomovitch@mandriva.org> 0.2.0-1mdv2007.0
+ Revision: 125026
- fix build dependencies
- new version
- new version

* Wed Jan 17 2007 Guillaume Rousse <guillomovitch@mandriva.org> 0.1.10-1mdv2007.1
+ Revision: 109906
- minor spec cleanup
- new version

* Wed Dec 13 2006 Guillaume Rousse <guillomovitch@mandriva.org> 0.1.9-1mdv2007.1
+ Revision: 96226
- new version
- rebuild for latest python

* Mon Oct 16 2006 Olivier Blin <oblin@mandriva.com> 0.1.7-3mdv2006.0
+ Revision: 65351
- remove libxenstore devel requires on x86_64 as well

* Sun Oct 15 2006 Olivier Blin <oblin@mandriva.com> 0.1.7-2mdv2007.1
+ Revision: 65070
- don't require devel(libxenstore), it is not versionned properly

* Sat Oct 14 2006 Olivier Blin <oblin@mandriva.com> 0.1.7-1mdv2006.0
+ Revision: 64654
- buildrequires python-devel
- buildrequires readline-devel
- buildrequires ncurses-devel
- buildrequires libxml2-devel
- buildrequires libxml-devel
- initial libvirt release
- Create libvirt

